#!/usr/bin/python3

import dodo
from sys import platform

from scripts.builder import process_tasks
from scripts import config
from scripts.translations import compile_translations
from scripts import version

if platform == 'msys':
	process_tasks(dodo.make_libbirdgems('libbirdgems.dll', []))
	process_tasks(dodo.make_libbirdfont('libbirdfont.dll', ['libbirdgems.dll']))
	process_tasks(dodo.make_birdfont_test('birdfont-test.exe', ['libbirdgems.so', 'libbirdfont.so']))
elif platform == 'darwin':
	gems = "libbirdgems." + str(version.LIBBIRDGEMS_SO_VERSION) + '.dylib'
	bird = "libbirdfont." + str(version.SO_VERSION) + '.dylib';
	process_tasks(dodo.make_libbirdgems(gems, []))
	process_tasks(dodo.make_libbirdfont(bird, [gems]))
	process_tasks(dodo.task_man())
else:
	process_tasks(dodo.task_libbirdgems())
	process_tasks(dodo.task_libbirdfont())
	process_tasks(dodo.make_birdfont_test('birdfont-test', ['libbirdgems.so', 'libbirdfont.so']))

process_tasks(dodo.task_birdfont())
process_tasks(dodo.task_birdfont_autotrace())
process_tasks(dodo.task_birdfont_export())
process_tasks(dodo.task_birdfont_import())
process_tasks(dodo.task_man())

compile_translations()

print('Done')



#!/usr/bin/python3
import subprocess
import os

def task_update_translations ():
	subprocess.check_output ("xgettext --language=vala --keyword=t_ --add-comments=/ --from-code=utf-8 --output=./po/birdfont.pot ./libbirdfont/*.vala ./birdfont/*.vala ./birdfont-export/*.vala ./birdfont-autotrace/*.vala", shell=True)

	for file in os.listdir('./po'):
		if file == "birdfont.pot": continue

		try:
			if file.index ('.po') == -1: continue		
		except:
			continue

		loc = file.replace (".po", "")
		d = "./po/" + loc + ".po"

		subprocess.check_output ("wget -O build/" + loc + ".po.zip http://pootle.locamotion.org/" + loc + "/birdfont/export/zip", shell=True)
		subprocess.check_output ("unzip build/" + loc + ".po.zip", shell=True)
		subprocess.check_output ("mv " + loc + ".po " + d, shell=True)
		
		subprocess.check_output ("msgmerge " + d + " ./po/birdfont.pot > " + loc + ".po.new", shell=True)
		subprocess.check_output ("mv " + loc + ".po.new " + d, shell=True)
	
	return  {
		'actions': ['echo "done updating translations"'],
	}


task_update_translations ()



#!/usr/bin/python
"""
Copyright (C) 2013 Johan Mattsson

This library is free software; you can redistribute it and/or modify 
it under the terms of the GNU Lesser General Public License as 
published by the Free Software Foundation; either version 3 of the 
License, or (at your option) any later version.

This library is distributed in the hope that it will be useful, but 
WITHOUT ANY WARRANTY; without even the implied warranty of 
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
Lesser General Public License for more details.
"""

import build
from translations import compile_translations
import configfile
from run import run
import version

prefix = ""
valac = "valac"
valaflags = "--define ANDROID --vapidir=/opt/birdfont/include --vapidir=./ --pkg android"
cc = ""
cflags = ""
ldflags = ""
library_cflags = ""
library_ldflags = ""
library = "libbirdfont.so" 

configfile.write_config (prefix)
compile_translations()

build.libbirdgems(prefix, cc, cflags, library_ldflags, valac, valaflags, library)
run ("mkdir -p build/libbirdgems/jni");
run ("cp scripts/AndroidBirdGems.mk build/libbirdgems/jni/Android.mk");
run ("cp build/libbirdgems/*.c build/libbirdgems/jni/");
run ("cd build/libbirdgems/jni && ndk-build");
run ("cp -ra build/libbirdgems/libs/armeabi/libbirdgems.so build/");

build.libbirdxml(prefix, cc, cflags, library_ldflags, valac, valaflags, library)
run ("mkdir -p build/libbirdxml/jni");
run ("cp scripts/AndroidBirdXml.mk build/libbirdxml/jni/Android.mk");
run ("cp build/libbirdxml/*.c build/libbirdxml/jni/");
run ("cd build/libbirdxml/jni && ndk-build");
run ("cp -ra build/libbirdxml/libs/armeabi/libbirdxml.so build/");

build.libbirdfont(prefix, cc, cflags, library_ldflags, valac, valaflags, library)
run ("mkdir -p build/libbirdfont/jni");
run ("cp scripts/AndroidBirdFont.mk build/libbirdfont/jni/Android.mk");
run ("cp build/libbirdfont/*.c build/libbirdfont/jni/");
run ("cd build/libbirdfont/jni && ndk-build");
run ("cp -ra build/libbirdfont/libs/armeabi/libbirdfont.so build/");

print ("Done")



#!/usr/bin/python3
"""
Copyright (C) 2012, 2013 Eduardo Naufel Schettino and Johan Mattsson

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.
"""

from . import version

VERSION = version.VERSION

def write_config (prefix):
    print ("Writing Config.vala")

    vars = (('VERSION', VERSION),
        ('PREFIX', prefix),
        )

    f = open('./libbirdfont/Config.vala', 'w+')
    f.write("// Don't edit this file -- it is generated by the build script\n")
    f.write("namespace BirdFont {\n")

    var_line = '    internal static const string %s = "%s";\n'
    for name, value in vars:
        f.write(var_line % (name, value))

    f.write("}")

def write_compile_parameters(prefix, dest, cc, gee, valac, pkg_config,
                             non_null, valacflags, cflags, ldflags):
    settings = {
        'prefix': prefix,
        'dest': dest,
        'cc': cc,
        'cflags': cflags,
        'ldflags': ldflags,
        'valac': valac,
        'valacflags': valacflags,
        'pkg-config': pkg_config,
        'non_null': '--enable-experimental-non-null' if non_null else '',
        'gee': gee,
    }
    def autoquote(v):
        if isinstance(v, str):
            return '"' + v + '"'
        else:
            return str(v)

    f = open('./scripts/config.py', 'w+')
    f.write("#!/usr/bin/python3\n")
    for k, v in settings.items():
        f.write("%s = %s\n" % (k.upper().replace('-', '_'), autoquote(v)))

    f.write("SETTINGS = {\n")
    for k, v in settings.items():
        f.write('    "%s": %s,\n' % (k, autoquote(v)))
    f.write("}\n")



#!/usr/bin/python3
"""
Copyright (C) 2015 Johan Mattsson
License: LGPL
"""

import glob
from optparse import OptionParser

try:
    from scripts.run import run
except ImportError:
    from run import run
    
def completeness (pofile):
    """ Returns the completeness of the translation in percent """
    with open (pofile, 'r', encoding='utf-8') as f:
        content = f.readlines ()

    translated = 0.0
    untranslated = 0.0
    msg = ""
    original = ""
    for line in content:
        if line.startswith ("#"):
            continue
        if line.strip () == "":
            continue
        if line.startswith ("msgid"):
            if not original == "msgstr \"\"":
                if msg.strip () == "" and not original.strip () == "":
                    untranslated = untranslated + 1
                else:
                    translated = translated + 1
            original = line
            msg = ""
        if line.startswith ("msgstr") or line.startswith ("\""):
            msg += line.replace ("msgstr", "").replace ("\"", "")
        
    if msg == "" and not original == "":
        untranslated = untranslated + 1
    else:
        translated = translated + 1
        
    total = translated + untranslated
    
    if total == 0:
        return 0
    
    return (translated / total) * 100;
   
   
parser = OptionParser()
parser.add_option("-t", "--threshold", dest="threshold", help="completeness threshold in percens", metavar="THRESHOLD")
parser.add_option("-i", "--incomplete", dest="incomplete", action="store_true", default=False, help="move incomplete translations to the folder for incomplete translations", metavar="MOVE_INCOMPLETE")
parser.add_option("-r", "--remove-compiled", dest="compiled", action="store_true", default=False, help="remove compiled incomplete translations", metavar="MOVE_COMPILED_INCOMPLETE")
(options, args) = parser.parse_args()

if not options.threshold:
    for pofile in glob.glob('po/*.po'):
        completed = completeness (pofile)
        print (pofile + " " + str (completed) + "%")
elif options.compiled:
    for pofile in glob.glob('po/*.po'):
        completed = completeness (pofile)
        podir = pofile.replace ("po/", "")
        podir = podir.replace (".po", "")
        podir = podir.replace ("\\", "/")
        if completed >= float (options.threshold):
            print ("Releasing " + podir)
        else:
            print ("Removing incomplete translation " + podir)
            run ("mkdir -p build/incomplete")
            run ("rm -r build/locale/" + podir) 
elif options.incomplete:
    for pofile in glob.glob('po/*.po'):
        completed = completeness (pofile)
        if completed >= float (options.threshold):
            print ("Releasing " + pofile)
        else:
            print ("Moving incomplete translation " + pofile + " to po/incomplete/")
            run ("mkdir -p po/incomplete")
            run ("mv " + pofile + " po/incomplete/") 
else:
    for pofile in glob.glob('po/*.po'):
        completed = completeness (pofile)
        if completed >= float (options.threshold):
            print (pofile)



#!/usr/bin/python3
"""
Copyright (C) 2013, 2014 Johan Mattsson

This library is free software; you can redistribute it and/or modify 
it under the terms of the GNU Lesser General Public License as 
published by the Free Software Foundation; either version 3 of the 
License, or (at your option) any later version.

This library is distributed in the hope that it will be useful, but 
WITHOUT ANY WARRANTY; without even the implied warranty of 
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU 
Lesser General Public License for more details.
"""

VERSION = '2.21.1'
SO_VERSION_MAJOR = '36'
SO_VERSION_MINOR = '0'
SO_VERSION = SO_VERSION_MAJOR + '.' + SO_VERSION_MINOR

LIBBIRDGEMS_SO_VERSION_MAJOR = '0'
LIBBIRDGEMS_SO_VERSION_MINOR = '0'
LIBBIRDGEMS_SO_VERSION = LIBBIRDGEMS_SO_VERSION_MAJOR + '.' + LIBBIRDGEMS_SO_VERSION_MINOR;



#!/usr/bin/python3
"""
Copyright (C) 2013 Johan Mattsson

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.
"""

import glob

try:
    from scripts.run import run
except ImportError:
    from run import run

def compile_translations ():
    for f_name in glob.glob('po/*.po'):
        lang = f_name.replace ("po/", "").replace (".po", "")
        lang = lang.replace ("\\", "/")
        build_path = "build/locale/" + lang + "/LC_MESSAGES/"
        target = build_path + "birdfont.mo"
        run ("mkdir -p " + build_path);
        f_name = f_name.replace ("\\", "/")
        run ("msgfmt --output=%s %s" % (target, f_name));
        



#!/usr/bin/python3
"""
Copyright (C) 2013 Johan Mattsson

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.
"""

import subprocess

def run(cmd):
	cmd = "sh -c \"" + cmd.replace ("\"", "\\\"") + "\""
	process = subprocess.Popen (cmd, shell=True)
	process.communicate()[0]
	if not process.returncode == 0:
		print("Error: " + cmd)
		exit(1)
